Signed-off-by: Mike Holmes <[email protected]>
---
 configure.ac                                     |  2 +-
 platform/linux-generic/include/api/odp_version.h | 39 ++++++++++++------------
 2 files changed, 20 insertions(+), 21 deletions(-)

diff --git a/configure.ac b/configure.ac
index aa94034..456c5fa 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,5 +1,5 @@
 AC_PREREQ([2.5])
-AC_INIT([OpenDataPlane], [0.2], [[email protected]])
+AC_INIT([OpenDataPlane], [0.3.0], [[email protected]])
 AM_INIT_AUTOMAKE([subdir-objects])
 AC_CONFIG_SRCDIR([helper/config.h.in])
 AM_CONFIG_HEADER([helper/config.h])
diff --git a/platform/linux-generic/include/api/odp_version.h 
b/platform/linux-generic/include/api/odp_version.h
index 3a75201..0e5b8e0 100644
--- a/platform/linux-generic/include/api/odp_version.h
+++ b/platform/linux-generic/include/api/odp_version.h
@@ -23,30 +23,32 @@ extern "C" {
  */
 
 /**
  * ODP API main version
  *
- * Introduction of major new features or changes. APIs with different major
+ * Introduction of major new features or changes that make
+ * very significant changes to the API. APIs with different
  * versions are likely not backward compatible.
  */
-#define ODP_VERSION_API_MAIN  0
+#define ODP_VERSION_API_GENERATION 0
 
 /**
  * ODP API sub version
  *
- * Introduction of additional features or minor changes. APIs with common
- * major version and different sub versions may be backward compatible (if only
- * additions).
+ * Introduction of major new features or changes. APIs with different major
+ * versions are likely not backward compatible.
  */
-#define ODP_VERSION_API_SUB   0
+#define ODP_VERSION_API_MAJOR 3
 
 /**
- * ODP API bug correction version
- *
- * Bug corrections to the API files. APIs with the same major and sub
- * versions, but different bug correction versions are backward compatible.
+ * ODP API minor version
+ * Minor version is incremented when introducing backward compatible changes
+ * to the API.
+ * For an API with common generation and major version, but with different
+ * minor numbers the two versions are backward compatible.
+ * Changes to the test suite will increment this digit.
+ * Changes to linux-generic will not increment this digit.
  */
-#define ODP_VERSION_API_BUG   1
-
+#define ODP_VERSION_API_MINOR 0
 
 /** @internal Version string expand */
 #define ODP_VERSION_STR_EXPAND(x)  #x
@@ -56,10 +58,9 @@ extern "C" {
 
 /** @internal API version string */
 #define ODP_VERSION_API_STR \
-ODP_VERSION_TO_STR(ODP_VERSION_API_MAIN) "."\
-ODP_VERSION_TO_STR(ODP_VERSION_API_SUB) "."\
-ODP_VERSION_TO_STR(ODP_VERSION_API_BUG)
-
+ODP_VERSION_TO_STR(ODP_VERSION_API_GENERATION) "."\
+ODP_VERSION_TO_STR(ODP_VERSION_API_MAJOR) "."\
+ODP_VERSION_TO_STR(ODP_VERSION_API_MINOR)
 
 /**
  * Returns ODP API version string
@@ -69,8 +70,6 @@ static inline const char *odp_version_api_str(void)
        return ODP_VERSION_API_STR;
 }
 
-
-
 /**
  * @}
  */
@@ -23,30 +23,32 @@ extern "C" {
 
 /**
- * ODP API main version
+ * ODP API generation version
  *
@@ -23,30 +23,32 @@ extern "C" {
 
 /**
- * ODP API sub version
+ * ODP API major version
  *
-- 
2.1.0


_______________________________________________
lng-odp mailing list
[email protected]
http://lists.linaro.org/mailman/listinfo/lng-odp

Reply via email to